==> gsequencer_6.5.2.orig.tar.gz: gsequencer-6.5.2/ags/audio/fx/ags_fx_vst3_recycling.c <==
/* GSequencer - Advanced GTK Sequencer
 * Copyright (C) 2005-2021 Joël Krähemann
 *
 * This file is part of GSequencer.
 *
 * GSequencer is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * GSequencer is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with GSequencer.  If not, see <http://www.gnu.org/licenses/>.
 */

#include <ags/audio/fx/ags_fx_vst3_recycling.h>

#include <ags/audio/fx/ags_fx_vst3_audio_signal.h>

#include <ags/i18n.h>

void ags_fx_vst3_recycling_class_init(AgsFxVst3RecyclingClass *fx_vst3_recycling);
void ags_fx_vst3_recycling_init(AgsFxVst3Recycling *fx_vst3_recycling);
void ags_fx_vst3_recycling_dispose(GObject *gobject);
void ags_fx_vst3_recycling_finalize(GObject *gobject);

/**
 * SECTION:ags_fx_vst3_recycling
 * @short_description: fx vst3 recycling
 * @title: AgsFxVst3Recycling
 * @section_id:
 * @include: ags/audio/fx/ags_fx_vst3_recycling.h
 *
 * The #AgsFxVst3Recycling class provides ports to the effect processor.
 */

static gpointer ags_fx_vst3_recycling_parent_class = NULL;

const gchar *ags_fx_vst3_recycling_plugin_name = "ags-fx-vst3";

GType
ags_fx_vst3_recycling_get_type()
{
  static volatile gsize g_define_type_id__volatile = 0;

  if(g_once_init_enter (&g_define_type_id__volatile)){
    GType ags_type_fx_vst3_recycling = 0;

    static const GTypeInfo ags_fx_vst3_recycling_info = {
      sizeof (AgsFxVst3RecyclingClass),
      NULL, /* base_init */
      NULL, /* base_finalize */
      (GClassInitFunc) ags_fx_vst3_recycling_class_init,
      NULL, /* class_finalize */
      NULL, /* class_recycling */
      sizeof (AgsFxVst3Recycling),
      0,    /* n_preallocs */
      (GInstanceInitFunc) ags_fx_vst3_recycling_init,
    };

    ags_type_fx_vst3_recycling = g_type_register_static(AGS_TYPE_FX_NOTATION_RECYCLING,
							"AgsFxVst3Recycling",
							&ags_fx_vst3_recycling_info,
							0);

    g_once_init_leave(&g_define_type_id__volatile, ags_type_fx_vst3_recycling);
  }

  return g_define_type_id__volatile;
}

void
ags_fx_vst3_recycling_class_init(AgsFxVst3RecyclingClass *fx_vst3_recycling)
{
  GObjectClass *gobject;

  ags_fx_vst3_recycling_parent_class = g_type_class_peek_parent(fx_vst3_recycling);

  /* GObjectClass */
  gobject = (GObjectClass *) fx_vst3_recycling;

  gobject->dispose = ags_fx_vst3_recycling_dispose;
  gobject->finalize = ags_fx_vst3_recycling_finalize;
}

void
ags_fx_vst3_recycling_init(AgsFxVst3Recycling *fx_vst3_recycling)
{
  AGS_RECALL(fx_vst3_recycling)->name = "ags-fx-vst3";
  AGS_RECALL(fx_vst3_recycling)->version = AGS_RECALL_DEFAULT_VERSION;
  AGS_RECALL(fx_vst3_recycling)->build_id = AGS_RECALL_DEFAULT_BUILD_ID;
  AGS_RECALL(fx_vst3_recycling)->xml_type = "ags-fx-vst3-recycling";

  AGS_RECALL(fx_vst3_recycling)->child_type = AGS_TYPE_FX_VST3_AUDIO_SIGNAL;
}

void
ags_fx_vst3_recycling_dispose(GObject *gobject)
{
  AgsFxVst3Recycling *fx_vst3_recycling;
  
  fx_vst3_recycling = AGS_FX_VST3_RECYCLING(gobject);
  
  /* call parent */
  G_OBJECT_CLASS(ags_fx_vst3_recycling_parent_class)->dispose(gobject);
}

void
ags_fx_vst3_recycling_finalize(GObject *gobject)
{
  AgsFxVst3Recycling *fx_vst3_recycling;
  
  fx_vst3_recycling = AGS_FX_VST3_RECYCLING(gobject);

  /* call parent */
  G_OBJECT_CLASS(ags_fx_vst3_recycling_parent_class)->finalize(gobject);
}

/**
 * ags_fx_vst3_recycling_new:
 * @recycling: the #AgsRecycling
 *
 * Create a new instance of #AgsFxVst3Recycling
 *
 * Returns: the new #AgsFxVst3Recycling
 *
 * Since: 3.10.5
 */
AgsFxVst3Recycling*
ags_fx_vst3_recycling_new(AgsRecycling *recycling)
{
  AgsFxVst3Recycling *fx_vst3_recycling;

  fx_vst3_recycling = (AgsFxVst3Recycling *) g_object_new(AGS_TYPE_FX_VST3_RECYCLING,
							  "source", recycling,
							  NULL);

  return(fx_vst3_recycling);
}

==> gsequencer_7.7.5.orig.tar.gz: gsequencer-7.7.5/ags/audio/fx/ags_fx_vst3_recycling.c <==
/* GSequencer - Advanced GTK Sequencer
 * Copyright (C) 2005-2021 Joël Krähemann
 *
 * This file is part of GSequencer.
 *
 * GSequencer is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * GSequencer is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with GSequencer.  If not, see <http://www.gnu.org/licenses/>.
 */

#include <ags/audio/fx/ags_fx_vst3_recycling.h>

#include <ags/audio/fx/ags_fx_vst3_audio_signal.h>

#include <ags/i18n.h>

void ags_fx_vst3_recycling_class_init(AgsFxVst3RecyclingClass *fx_vst3_recycling);
void ags_fx_vst3_recycling_init(AgsFxVst3Recycling *fx_vst3_recycling);
void ags_fx_vst3_recycling_dispose(GObject *gobject);
void ags_fx_vst3_recycling_finalize(GObject *gobject);

/**
 * SECTION:ags_fx_vst3_recycling
 * @short_description: fx vst3 recycling
 * @title: AgsFxVst3Recycling
 * @section_id:
 * @include: ags/audio/fx/ags_fx_vst3_recycling.h
 *
 * The #AgsFxVst3Recycling class provides ports to the effect processor.
 */

static gpointer ags_fx_vst3_recycling_parent_class = NULL;

const gchar *ags_fx_vst3_recycling_plugin_name = "ags-fx-vst3";

GType
ags_fx_vst3_recycling_get_type()
{
  static gsize g_define_type_id__static = 0;

  if(g_once_init_enter(&g_define_type_id__static)){
    GType ags_type_fx_vst3_recycling = 0;

    static const GTypeInfo ags_fx_vst3_recycling_info = {
      sizeof (AgsFxVst3RecyclingClass),
      NULL, /* base_init */
      NULL, /* base_finalize */
      (GClassInitFunc) ags_fx_vst3_recycling_class_init,
      NULL, /* class_finalize */
      NULL, /* class_recycling */
      sizeof (AgsFxVst3Recycling),
      0,    /* n_preallocs */
      (GInstanceInitFunc) ags_fx_vst3_recycling_init,
    };

    ags_type_fx_vst3_recycling = g_type_register_static(AGS_TYPE_FX_NOTATION_RECYCLING,
							"AgsFxVst3Recycling",
							&ags_fx_vst3_recycling_info,
							0);

    g_once_init_leave(&g_define_type_id__static, ags_type_fx_vst3_recycling);
  }

  return(g_define_type_id__static);
}

void
ags_fx_vst3_recycling_class_init(AgsFxVst3RecyclingClass *fx_vst3_recycling)
{
  GObjectClass *gobject;

  ags_fx_vst3_recycling_parent_class = g_type_class_peek_parent(fx_vst3_recycling);

  /* GObjectClass */
  gobject = (GObjectClass *) fx_vst3_recycling;

  gobject->dispose = ags_fx_vst3_recycling_dispose;
  gobject->finalize = ags_fx_vst3_recycling_finalize;
}

void
ags_fx_vst3_recycling_init(AgsFxVst3Recycling *fx_vst3_recycling)
{
  AGS_RECALL(fx_vst3_recycling)->name = "ags-fx-vst3";
  AGS_RECALL(fx_vst3_recycling)->version = AGS_RECALL_DEFAULT_VERSION;
  AGS_RECALL(fx_vst3_recycling)->build_id = AGS_RECALL_DEFAULT_BUILD_ID;
  AGS_RECALL(fx_vst3_recycling)->xml_type = "ags-fx-vst3-recycling";

  AGS_RECALL(fx_vst3_recycling)->child_type = AGS_TYPE_FX_VST3_AUDIO_SIGNAL;
}

void
ags_fx_vst3_recycling_dispose(GObject *gobject)
{
  AgsFxVst3Recycling *fx_vst3_recycling;
  
  fx_vst3_recycling = AGS_FX_VST3_RECYCLING(gobject);
  
  /* call parent */
  G_OBJECT_CLASS(ags_fx_vst3_recycling_parent_class)->dispose(gobject);
}

void
ags_fx_vst3_recycling_finalize(GObject *gobject)
{
  AgsFxVst3Recycling *fx_vst3_recycling;
  
  fx_vst3_recycling = AGS_FX_VST3_RECYCLING(gobject);

  /* call parent */
  G_OBJECT_CLASS(ags_fx_vst3_recycling_parent_class)->finalize(gobject);
}

/**
 * ags_fx_vst3_recycling_new:
 * @recycling: the #AgsRecycling
 *
 * Create a new instance of #AgsFxVst3Recycling
 *
 * Returns: the new #AgsFxVst3Recycling
 *
 * Since: 3.10.5
 */
AgsFxVst3Recycling*
ags_fx_vst3_recycling_new(AgsRecycling *recycling)
{
  AgsFxVst3Recycling *fx_vst3_recycling;

  fx_vst3_recycling = (AgsFxVst3Recycling *) g_object_new(AGS_TYPE_FX_VST3_RECYCLING,
							  "source", recycling,
							  NULL);

  return(fx_vst3_recycling);
}
